SWDEV-470698 - fix formatting, add format check workflow (#657)
This commit is contained in:
zatwierdzone przez
GitHub
rodzic
5840940caa
commit
f7338717ae
@@ -23,8 +23,7 @@ THE SOFTWARE.
|
||||
/**
|
||||
* This kernel writes to memory allocated in ker_Alloc_MultCodeObj<<<>>>.
|
||||
*/
|
||||
extern "C" __global__ void ker_Write_MultCodeObj(int **dev_mem,
|
||||
int value) {
|
||||
extern "C" __global__ void ker_Write_MultCodeObj(int** dev_mem, int value) {
|
||||
int myId = threadIdx.x + blockDim.x * blockIdx.x;
|
||||
// Check allocated memory in all threads in block before access
|
||||
if (*dev_mem == nullptr) {
|
||||
|
||||
Reference in New Issue
Block a user